@@ -1,7 +1,7 @@
 /*
     dllloader
     (C)Copyright 2000, 2001 by Hiroshi Takekawa
-    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 2002-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,6 +38,9 @@
 #ifdef __linux__
 # include <asm/ldt.h>
 # include <asm/unistd.h>
+# ifdef HAVE_STRUCT_USER_DESC
+#  define modify_ldt_ldt_s user_desc
+# endif
 #elif defined(HAVE_I386_SET_LDT)
 # include <machine/segments.h>
 # include <machine/sysarch.h>
@@ -167,7 +170,8 @@ static int install_fs(void)
 	return 0;
 }
 #elif defined(HAVE_I386_SET_LDT)
-static int install_fs(void)
+static int
+install_fs(void)
 {
 	unsigned int fs;
 	union descriptor d;
@@ -195,7 +199,11 @@ static int install_fs(void)
 	d.sd.sd_p=1;
 	d.sd.sd_def32=1;
 	d.sd.sd_gran=1;
+#if defined(__FreeBSD__) && defined(LDT_AUTO_ALLOC)
+#define LDT_SEL_START LDT_AUTO_ALLOC
+#else
 #define LDT_SEL_START 0xb
+#endif
 	ret=i386_set_ldt(LDT_SEL_START,&d,1);
 	if (ret<0) {
 		g_message("i386_set_ldt");
