@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,11 @@
 #include "vmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 #define THREAD_MODE_EXIT 0
 #define THREAD_MODE_OPEN 1
 #define THREAD_MODE_SAVE 2
@@ -34,40 +39,45 @@
 #endif /* not USE_THREAD */
 
 
-typedef struct ThreadList_Tag {
-	gboolean userbreak;	/* TRUE:³,FALSE:׵ */
-	gint mode;			/* 0:λ,1:,2:¸,3:ե졼,4:ȿž */
-	gint percent;		/* ʹԾ(0...100) */
+typedef struct ThreadList_Tag
+{
+  gboolean userbreak;   /* ja:TRUE:継続,FALSE:中断要求 */
+  gint mode;            /* ja:0:終了,1:開く,2:保存,3:フレーム数,4:反転 */
+  gint percent;         /* ja:進行状況(0...100) */
 #ifdef USE_THREAD
-	GThread *id;
+  GThread *id;
 #else /* not USE_THREAD */
-	gint id;
+  gint id;
 #endif /* not USE_THREAD */
 } ThreadList;
 
 
 /******************************************************************************
 *                                                                             *
-* åɴؿ                                                              *
+* ja:スレッド関数群                                                           *
 *                                                                             *
 ******************************************************************************/
-/*	ꥹȤ˲ä
-	  id,åID
-	mode,⡼(0:λ,1:,2:¸,3:ե졼,4:ȿž)
-	file,ե̾
-	 RET,TRUE:ｪλ,FALSE:顼											*/
+/*  ja:リストに加える
+      id,スレッドID
+    mode,モード(0:終了,1:開く,2:保存,3:フレーム数,4:反転)
+    file,ファイル名
+     RET,TRUE:正常終了,FALSE:エラー                                         */
 #ifdef USE_THREAD
 gboolean
-thread_insert (GThread *id, const gint mode, const gchar *file);
+thread_insert (GThread     *id,
+               const gint   mode,
+               const gchar *file);
 #else /* not USE_THREAD */
 gboolean
-thread_insert (gint id, const gint mode, const gchar *file);
+thread_insert (gint          id,
+               const gint    mode,
+               const gchar *file);
 #endif /* not USE_THREAD */
 
 
-/*	ꥹȤ
-	 id,åID
-	RET,TRUE:ｪλ,FALSE:顼											*/
+/*  ja:リストから削除する
+     id,スレッドID
+    RET,TRUE:正常終了,FALSE:エラー                                          */
 #ifdef USE_THREAD
 gboolean
 thread_delete (GThread *id);
@@ -77,29 +87,36 @@ thread_delete(gint id);
 #endif /* not USE_THREAD */
 
 
-/*	ꥹȤ򹹿
-	     id,åID
-	percent,ʹԾ
-	    RET,TRUE:³,FALSE:											*/
+/*  ja:リストを更新する
+         id,スレッドID
+    percent,進行状況
+        RET,TRUE:継続,FALSE:中断                                            */
 #ifdef USE_THREAD
 gboolean
-thread_idling (GThread *id, const gint percent);
+thread_idling (GThread    *id,
+               const gint  percent);
 #else /* not USE_THREAD */
 gboolean
-thread_idling (gint id, const gint percent);
+thread_idling (gint       id,
+               const gint percent);
 #endif /* not USE_THREAD */
 
 
-/*	åɤߤ
-	all,TRUE:٤ƤΥå,FALSE:򤵤줿åɤΤ
-	RET,TRUE:ｪλ,FALSE:顼											*/
+/*  ja:スレッドを停止させる
+    all,TRUE:すべてのスレッド,FALSE:選択されたスレッドのみ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
 gboolean
 thread_break (const gboolean all);
 
 
-/*	ץνλ(Ωå)											*/
+/*  ja:プログラムの終了(独立スレッド)                                       */
 void *
 close_program (void);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
