@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,16 +23,27 @@
 #include "vmaid.h"
 
 
-typedef struct ToolBar_Tag {
-	gchar *name;
-	gchar **xpm;
-	GtkItemFactoryCallback callback;
-	gpointer user_data;
-	GtkWidget *item;
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
+typedef struct ToolBar_Tag
+{
+  gchar                   *name;
+  gchar                  **xpm;
+  GtkItemFactoryCallback   callback;
+  gpointer                 user_data;
+  GtkWidget               *item;
 } ToolBar;
 
 
 extern ToolBar toolbar_items[];
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
