@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,24 @@
 #include "vmaid.h"
 
 
-void version_dialog(void);
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
+/******************************************************************************
+*                                                                             *
+* ja:バージョン情報関数群                                                     *
+*                                                                             *
+******************************************************************************/
+/*  ja:バージョン表示                                                       */
+void
+version_dialog (void);
+
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 
 #endif
